pub fn loc_time_to_sun(
lat: f64,
lon: f64,
datetime: NaiveDateTime,
) -> Result<GlobalLighting, SpaError>Expand description
Get the mao lighting for a location and time
pub fn loc_time_to_sun(
lat: f64,
lon: f64,
datetime: NaiveDateTime,
) -> Result<GlobalLighting, SpaError>Get the mao lighting for a location and time